from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, Int, String, Float, Directory

Runchicago_R_V0_1_0 = CommandToolBuilder(tool="runChicago.R", base_command=["runChicago.R"], inputs=[ToolInput(tag="in_print_memory", input_type=Boolean(optional=True), prefix="--print-memory", doc=InputDocumentation(doc="Should chicagoPipeline print out memory use?")), ToolInput(tag="in_rda", input_type=Boolean(optional=True), prefix="--rda", doc=InputDocumentation(doc="Save the Chicago object as an RDa image (instead of the default RDS)")), ToolInput(tag="in_save_df_only", input_type=Boolean(optional=True), prefix="--save-df-only", doc=InputDocumentation(doc="Save only the data part of the Chicago object, as a data frame (for compatibility)")), ToolInput(tag="in_examples_full_range", input_type=Boolean(optional=True), prefix="--examples-full-range", doc=InputDocumentation(doc="Also plot examples for the full distance range")), ToolInput(tag="in_en_full_cis_range", input_type=Boolean(optional=True), prefix="--en-full-cis-range", doc=InputDocumentation(doc="Assess the enrichment for features for the full distance range [same chromosome only; use --en-trans in addition to include trans-interactions] (can be very slow!)")), ToolInput(tag="in_en_trans", input_type=Boolean(optional=True), prefix="--en-trans", doc=InputDocumentation(doc="Include trans-interactions into enrichment analysis")), ToolInput(tag="in_features_only", input_type=Boolean(optional=True), prefix="--features-only", doc=InputDocumentation(doc="Re-run feature enrichment analysis with Chicago output files. With this option, <input-files> must be either a single Rds file (must contain full Chicago objects) or '-', in which case the file location will be inferred automatically from <output-prefix> and files added to the corresponding folder.")), ToolInput(tag="in_opts", input_type=File(optional=True), prefix="--opts", doc=InputDocumentation(doc="RDS file containing argument values")), ToolInput(tag="in_settings_file", input_type=File(optional=True), prefix="--settings-file", doc=InputDocumentation(doc="Full path to Chicago settings file")), ToolInput(tag="in_design_dir", input_type=File(optional=True), prefix="--design-dir", doc=InputDocumentation(doc="Folder with capture design files (note the settings file has priority over these) [default: ]")), ToolInput(tag="in_cut_off", input_type=Int(optional=True), prefix="--cutoff", doc=InputDocumentation(doc="Score cutoff for writing out peaks and testing feature enrichment [default: 5]")), ToolInput(tag="in_export_format", input_type=File(optional=True), prefix="--export-format", doc=InputDocumentation(doc="File format for writing out peaks: one or more of the following: seqMonk,interBed,washU_text,washU_track (comma-separated) [default: washU_text]")), ToolInput(tag="in_export_order", input_type=String(optional=True), prefix="--export-order", doc=InputDocumentation(doc="Should the results be ordered by 'score' or genomic 'position'? [default: position]")), ToolInput(tag="in_examples_prox_dist", input_type=Float(optional=True), prefix="--examples-prox-dist", doc=InputDocumentation(doc="The distance limit for plotting 'proximal' examples [default: 1e+06]")), ToolInput(tag="in_output_dir", input_type=File(optional=True), prefix="--output-dir", doc=InputDocumentation(doc="The name of the output directory (can be a full path) [default: <output-prefix>]")), ToolInput(tag="in_en_feat_files", input_type=String(optional=True), prefix="--en-feat-files", doc=InputDocumentation(doc="A comma-separated list of files with genomic feature coordinates for computing peaks' enrichment")), ToolInput(tag="in_en_feat_list", input_type=File(optional=True), prefix="--en-feat-list", doc=InputDocumentation(doc="Same as above but the supplied file contains the feature names and\nlocations of feature files (in the format <feature-name> <feature-file-location>")), ToolInput(tag="in_en_feat_folder", input_type=Directory(optional=True), prefix="--en-feat-folder", doc=InputDocumentation(doc="The folder, in which all feature files are located (if provided, --en-feature-file(s) don't need to list the full path)")), ToolInput(tag="in_en_min_dist", input_type=Int(optional=True), prefix="--en-min-dist", doc=InputDocumentation(doc="The lower distance limit for computing enrichment for features [default: 0]")), ToolInput(tag="in_en_max_dist", input_type=Int(optional=True), prefix="--en-max-dist", doc=InputDocumentation(doc="The upper distance limit for computing enrichment for features [default: 1e+06]")), ToolInput(tag="in_en_sample_no", input_type=Int(optional=True), prefix="--en-sample-no", doc=InputDocumentation(doc="The number of negative samples for computing enrichment for features [default: 100]"))], outputs=[ToolOutput(tag="out_export_format", output_type=File(optional=True), selector=InputSelector(input_to_select="in_export_format", type_hint=File()), doc=OutputDocumentation(doc="File format for writing out peaks: one or more of the following: seqMonk,interBed,washU_text,washU_track (comma-separated) [default: washU_text]")), ToolOutput(tag="out_output_dir", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_dir", type_hint=File()), doc=OutputDocumentation(doc="The name of the output directory (can be a full path) [default: <output-prefix>]"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Runchicago_R_V0_1_0().translate("wdl", allow_empty_container=True)

